==> nextcloud-17.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/accessibility/l10n/lv.js <==
OC.L10N.register(
    "accessibility",
    {
    "Dark theme" : "Tumšs motīvs",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Tumšais motīvs atslogo Tavas acis samazinot kopējo atspīdumu un spilgtumu. Tas joprojām atrodas izstrādes režīmā, tādēļ dod ziņu par jebkurām atrastajām problēmām.",
    "High contrast mode" : "Augsta kontrasta režīms",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Augsta kontrasta režīms atvieglo navigāciju. Vizuālā kvalitāte tiks samazināta, bet skaidrība paaugstināsies.",
    "Dyslexia font" : "Dislektisks fonts",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic ir bezmaksas fonts, kas veidots, lai mazinātu tipiskākos lasīšanas traucējumus, ko izraisa disleksija.",
    "Accessibility" : "Pieejamība",
    "Accessibility options for nextcloud" : "nextcloud Pieejamības uzstādījumi",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Piedāvā vairākus pieejamības uzstādījumus, kas atvieglo Nextcloud lietošanu.",
    "Web Content Accessibility Guidelines" : "Web Satura Pieejamības Vadīklas",
    "our issue tracker" : "mūsu problēmu izsekotājs",
    "our design team" : "mūsu dizaina komanda",
    "Enable" : "Iespējo",
    "High contrast theme" : "Augsta kontrasta motīvs",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Augsta kontrasta režīms atvieglo navigāciju. Vizuālā kvalitāte tiks samazināta, bet skaidrība paaugstināsies.",
    "Dark theme (beta)" : "Tumšs motīvs (beta)",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia. The typeface was created by Abelardo Gonzalez, who released it through an open-source license." : "OpenDyslexic ir bezmaksas fonts, kas veidots, lai mazinātu tipiskākos lasīšanas traucējumus, ko izraisa disleksija. Fontu radīja Abelardo Gonzalez, kurš to publicēja ar atvērtā koda licences starpniecību.",
    "Provides multiple accessibilities options to ease your use of nextcloud" : "Piedāvā vairākus pieejamības uzstādījumus, kas atvieglo nextcloud lietošanu.",
    "Themes" : "Motīvi",
    "Fonts" : "Fonti",
    "enabled" : "iespējots"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> nextcloud-19.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/accessibility/l10n/lv.js <==
OC.L10N.register(
    "accessibility",
    {
    "Dark theme" : "Tumšs motīvs",
    "Enable dark theme" : "Iespējot tumšo motīvu",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Tumšais motīvs atslogo Tavas acis samazinot kopējo atspīdumu un spilgtumu. Tas joprojām atrodas izstrādes režīmā, tādēļ dod ziņu par jebkurām atrastajām problēmām.",
    "High contrast mode" : "Augsta kontrasta režīms",
    "Enable high contrast mode" : "Iespējot augsta kontrasta režīmu",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Augsta kontrasta režīms atvieglo navigāciju. Vizuālā kvalitāte tiks samazināta, bet skaidrība paaugstināsies.",
    "Dyslexia font" : "Dislektisks fonts",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic ir bezmaksas fonts, kas veidots, lai mazinātu tipiskākos lasīšanas traucējumus, ko izraisa disleksija.",
    "Accessibility" : "Pieejamība",
    "Accessibility options for nextcloud" : "nextcloud Pieejamības uzstādījumi",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Piedāvā vairākus pieejamības uzstādījumus, kas atvieglo Nextcloud lietošanu.",
    "High contrast theme" : "Augsta kontrasta motīvs",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Augsta kontrasta režīms atvieglo navigāciju. Vizuālā kvalitāte tiks samazināta, bet skaidrība paaugstināsies.",
    "Dark theme (beta)" : "Tumšs motīvs (beta)",
    "Web Content Accessibility Guidelines" : "Web Satura Pieejamības Vadīklas",
    "our issue tracker" : "mūsu problēmu izsekotājs",
    "our design team" : "mūsu dizaina komanda",
    "Enable" : "Iespējo"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
